==> xfwm4-4.4.3.tar.bz2: xfwm4-4.4.3/src/poswin.h <==
/*      $Id: poswin.h 23704 2006-11-04 22:36:42Z olivier $

        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2, or (at your option)
        any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

        xfwm4    - (c) 2002-2006 Olivier Fourdan
          based on a patch from Joshua Blanton <jblanton@irg.cs.ohiou.edu>
 */

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#ifndef INC_POSWIN_H
#define INC_POSWIN_H

#include <glib.h>
#include <gdk/gdk.h>
#include <gdk/gdkx.h>
#include <gtk/gtk.h>
#include "client.h"

typedef struct _Poswin Poswin;
struct _Poswin
{
    GtkWidget *window;
    GtkWidget *label;
};

Poswin                  *poswinCreate                           (GdkScreen *);
void                     poswinSetPosition                      (Poswin *, 
                                                                 Client *);
void                     poswinDestroy                          (Poswin *);
void                     poswinShow                             (Poswin *);
void                     poswinHide                             (Poswin *);

#endif /* INC_POSWIN_H */

==> xfwm4-4.7.4.tar.bz2: xfwm4-4.7.4/src/poswin.h <==
/*      $Id$

        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2, or (at your option)
        any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., Inc., 51 Franklin Street, Fifth Floor, Boston,
        MA 02110-1301, USA.


        xfwm4    - (c) 2002-2010 Olivier Fourdan
          based on a patch from Joshua Blanton <jblanton@irg.cs.ohiou.edu>
 */

#ifndef INC_POSWIN_H
#define INC_POSWIN_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <glib.h>
#include <gdk/gdk.h>
#include <gdk/gdkx.h>
#include <gtk/gtk.h>
#include "client.h"

typedef struct _Poswin Poswin;
struct _Poswin
{
    GtkWidget *window;
    GtkWidget *label;
};

Poswin                  *poswinCreate                           (GdkScreen *);
void                     poswinSetPosition                      (Poswin *,
                                                                 Client *);
void                     poswinDestroy                          (Poswin *);
void                     poswinShow                             (Poswin *);
void                     poswinHide                             (Poswin *);

#endif /* INC_POSWIN_H */
